# -*- coding: utf-8 -*-
import logging
import os
import datetime


class Logger(logging.Logger):
    
    __log_dir = os.path.abspath(os.path.join(os.path.dirname(__file__),"../"))
    __log_file = "log{0}.txt".format(
        datetime.datetime.now().strftime("%Y-%m-%d"))
    __log_path = os.path.join(__log_dir, "logs", __log_file)

    def __init__(self, logger_name="logger", level="DEBUG"):
        super().__init__(logger_name)
        self.setLevel(level)

        console_fmt = logging.Formatter(
            fmt="%(name)s--->%(levelname)s--->%(asctime)s--->%(message)s")
        file_fmt = logging.Formatter(
            fmt="%(lineno)d--->%(name)s--->%(levelname)s--->%(asctime)s--->%(message)s")

        file_handler = logging.FileHandler(
            self.__log_path, mode="a", encoding="utf-8")
        file_handler.setLevel(level)
        file_handler.setFormatter(file_fmt)
        self.addHandler(file_handler)

        console_handler = logging.StreamHandler()
        console_handler.setLevel(level)
        console_handler.setFormatter(console_fmt)
        self.addHandler(console_handler)


if __name__ == "__main__":
    logger = Logger().debug("this is debug log info...")



import os
import os.path
import configparser
import xlrd


class Config:
    __config_dir = os.path.abspath(
        os.path.join(os.path.dirname(__file__), "../"))

    def __init__(self):
        self.__config_path = os.path.join(
            self.__config_dir, "cfg", "config.cfg")

    def get_config(self, section, key=None):
        config = configparser.ConfigParser()
        config.read(self.__config_path, encoding='utf-8')

        if key != None:
            return config.get(section, key)
        else:
            return config.items(section)

    def read_excel(self, excel_path, sheet_name):
        xls = xlrd.open_workbook(excel_path, formatting_info=True)
        sheet = xls.sheet_by_name(sheet_name)

        data_list =[]
        for row in range(1, sheet.nrows):
            data_list.append(sheet.row_values(row))
        return data_list

if __name__ == "__main__":
    print(os.path.abspath(os.path.join(os.path.dirname(__file__), "../")))
    print(Config().get_config("file"))
    print(Config().read_excel('分行配置表.xls', 'Sheet1'))



import xlwt
import xlrd


def read_xl(xl_path, sheet_name):
    xls = xlrd.open_workbook(xl_path, formatting_info=True)
    sheet = xls.sheet_by_name(sheet_name)
    for row_idx in range(1, sheet.nrows):
        for col_idx in range(sheet.ncols):
            print(sheet.cell(row_idx, col_idx).value)


def write_xl(xl_path, dict_list):
    xl = xlwt.Workbook(encoding="uft-8")
    sheet = xl.add_sheet("sheet1", cell_overwrite_ok=False)
    for row_idx in range(0, len(dict_list)):
        col_idx = 0
        for k, v in dict_list[row_idx].items():
            sheet.write(row_idx, col_idx, v)
            col_idx = col_idx+1
    xl.save(xl_path)


def write_txt(txt_path, dict_list):
    with open(txt_path, "w") as txt_file:
        for row_idx in range(0, len(dict_list)):
            col_idx = 0
            for k, v in dict_list[row_idx].items():
                txt_file.writelines(str(v)+"\n")
                col_idx = col_idx+1



from setuptools import find_packages, setup

setup(
    name='encoo',
    version='0.0.2',
    packages=find_packages(),
    install_requires=['xlwt>=1.3.0', 'xlrd>=2.0.1','configparser>=5.3.0']
)


#打包 python .\setup.py sdist bdist_wheel
#上传 twine upload dist/*
#安装 pip install encoo==0.0.1  -i https://www.pypi.org/simple/
